@@ -60,7 +60,10 @@ html_theme = "alabaster"
 # -- Options for intersphinx extension ---------------------------------------
 
 # Example configuration for intersphinx: refer to the Python standard library.
-intersphinx_mapping = {"https://docs.python.org/3/": None}
+intersphinx_mapping = dict(
+    python=("https://docs.python.org/3", None),
+    twisted=("https://twistedmatrix.com/documents/current/api/", None),
+)
 
 # -- Options for the linkcheck builder ------------------------------------
 
